@@ -47,13 +47,15 @@ public:
      */
     void interrupt() override;
 
+    QString internalCommand() override;
+
     /**
      * Call this function from session when JuliaServer ends evaluation of
      * this expression.
      *
      * This checks inline plots, exceptions and set appropriate result
      */
-    void finalize();
+    void finalize(const QString& output, const QString& error, bool wasException);
 
 private:
     /// If not empty, it's a filename of plot image file expression is awaiting
