@@ -21,11 +21,14 @@
 #include "imageentry.h"
 #include "worksheetimageitem.h"
 #include "actionbar.h"
+#include "lib/jupyterutils.h"
 
 #include <KLocalizedString>
 #include <QDebug>
 #include <QMenu>
 #include <QFileSystemWatcher>
+#include <QJsonValue>
+#include <QJsonObject>
 
 ImageEntry::ImageEntry(Worksheet* worksheet) : WorksheetEntry(worksheet)
 {
@@ -101,6 +104,47 @@ void ImageEntry::setContent(const QDomElement& content, const KZip& file)
     updateEntry();
 }
 
+void ImageEntry::setContentFromJupyter(const QJsonObject& cell)
+{
+    // No need use ImageEntry because without file this entry type are useless
+    Q_UNUSED(cell);
+    return;
+}
+
+QJsonValue ImageEntry::toJupyterJson()
+{
+    QJsonValue value;
+
+    if (!m_imagePath.isEmpty() && m_imageItem)
+    {
+        const QImage& image = m_imageItem->pixmap().toImage();
+        if (!image.isNull())
+        {
+            QJsonObject entry;
+            entry.insert(QLatin1String("cell_type"), QLatin1String("markdown"));
+
+            QJsonObject metadata;
+            QJsonObject size;
+            size.insert(QLatin1String("width"), image.size().width());
+            size.insert(QLatin1String("height"), image.size().height());
+            metadata.insert(Cantor::JupyterUtils::pngMime, size);
+            entry.insert(Cantor::JupyterUtils::metadataKey, metadata);
+
+            QString text(QLatin1String("<img src='attachment:image.png'>"));
+
+            QJsonObject attachments;
+            attachments.insert(QLatin1String("image.png"), Cantor::JupyterUtils::packMimeBundle(image, Cantor::JupyterUtils::pngMime));
+            entry.insert(QLatin1String("attachments"), attachments);
+
+            Cantor::JupyterUtils::setSource(entry, text);
+
+            value = entry;
+        }
+    }
+
+    return value;
+}
+
 QDomElement ImageEntry::toXml(QDomDocument& doc, KZip* archive)
 {
     Q_UNUSED(archive);
@@ -231,7 +275,7 @@ void ImageEntry::updateEntry()
                 size = imageSize(m_displaySize);
             // Hack: Eps images need to be scaled
             if (m_imagePath.endsWith(QLatin1String(".eps"), Qt::CaseInsensitive))
-                size /= worksheet()->epsRenderer()->scale();
+                size /= worksheet()->renderer()->scale();
             m_imageItem->setSize(size);
             qDebug() << size;
             m_textItem->setVisible(false);
